@@ -6,9 +6,9 @@ use serde::Serialize;
 
 use snafu::{ResultExt, Snafu};
 
-use crate::{service, Credentials};
+use dalloriam_cloud_protocol::hose::GenericMessage;
 
-use super::payload::GenericMessage;
+use crate::{service, Credentials};
 
 #[derive(Debug, Snafu)]
 pub enum HoseError {
@@ -46,7 +46,7 @@ impl HoseClient {
             .json(&msg)
             .send()
             .await
-            .context(DispatchError)?;
+            .context(DispatchSnafu)?;
 
         if !resp.status().is_success() {
             return match resp.status() {
